@@ -1,6 +1,4 @@
 #!/bin/sh
-# Save mac address
-MACADDR="`ifconfig wlan0 | sed -n 's/.*HWaddr \([0-9A-Fa-f:]\+\).*/\1/p'`"
 # Unload wifi modules
 rmmod wl1251_spi 2>/dev/null
 rmmod wl1251 2>/dev/null
@@ -17,6 +15,9 @@ insmod cfg80211.ko
 insmod mac80211.ko
 insmod wl1251.ko
 insmod wl1251_spi.ko
-# Restore mac address
-ifconfig wlan0 down hw ether "$MACADDR"
-
+# Restart wlancond
+#stop wlancond
+#start wlancond
+# Start up wlan0 interface
+#ifconfig wlan0 up
+#ifconfig wlan0 up; sh -c "airmon-ng start wlan0 >> /dev/null &" &
