@@ -79,14 +79,17 @@ class WlanDriverStatusPlugin(StatusMenuItem):
 		self.disableButtons = True
 		if driver == 0:
 			self.disableButton.set_active(False)
+			self.set_status_area_icon(gtk.gdk.pixbuf_new_from_file('/usr/share/icons/hicolor/48x48/hildon/wifi-off.png'))
 			#self.driverButton.setDisabled(True)
 		elif driver == 1:
 			self.disableButton.set_active(True)
 			self.driverButton.set_active(False)
+			self.set_status_area_icon()
 			#self.driverButton.setDisabled(False)
 		elif driver == 2:
 			self.disableButton.set_active(True)
 			self.driverButton.set_active(True)
+			self.set_status_area_icon()
 			#self.driverButton.setDisabled(False)
 		self.disableButtons = False
 
@@ -94,9 +97,12 @@ class WlanDriverStatusPlugin(StatusMenuItem):
 		f = open('/proc/modules', "r")
 		for line in f.readlines():
 			if line.startswith('wl1251'):
+				f.close()
 				return 2
 			if line.startswith('wl12xx'):
+				f.close()
 				return 1
+		f.close()
 		return 0
 
 class DriverLoader(Thread):
@@ -123,6 +129,10 @@ class DriverLoader(Thread):
 			if driver == 0:	self.Parent.Notifications.notify('Disabled WLAN')
 			elif driver == 1: self.Parent.Notifications.notify('Loaded Stock drivers')
 			elif driver == 2: self.Parent.Notifications.notify('Loaded Bleeding Edge drivers')
+		if driver > 0:
+			time.sleep(1)
+			proxy = self.Parent.bus.get_object('com.nokia.icd_ui', '/com/nokia/icd_ui', 'com.nokia.icd_ui')
+			proxy.show_conn_dlg(False)
 
 class Notifications:
 	def __init__(self, Parent):
